@@ -57,7 +57,7 @@ class Encoder:
         df = Snaplib().encode_dataframe(df)
         '''
 
-        if not isinstance(df, pd.core.frame.DataFrame):
+        if not isinstance(df_in, pd.core.frame.DataFrame):
             raise TypeError('The df must be a pandas.core.frame.DataFrame instance.')
 
         df = df_in.copy()
@@ -122,7 +122,7 @@ class Encoder:
         df = Snaplib().decode_dataframe(df)
         '''
 
-        if not isinstance(df, pd.core.frame.DataFrame):
+        if not isinstance(df_in, pd.core.frame.DataFrame):
             raise TypeError('The df must be a pandas.core.frame.DataFrame instance.')
 
         df = df_in.copy()
